@@ -1,6 +1,6 @@
 ########################################################################################
 #
-#    This file was generated using Parse::Eyapp version 1.134.
+#    This file was generated using Parse::Eyapp version 1.135.
 #
 # (c) Parse::Yapp Copyright 1998-2001 Francois Desarmenien.
 # (c) Parse::Eyapp Copyright 2006-2008 Casiano Rodriguez-Leon. Universidad de La Laguna.
@@ -222,6 +222,10 @@ sub process_production {
   return \@newrhs;
 }
 
+# Receives a specification of the RHS of a production like in:
+#       rhs([ $A, $val], name => $_[2], code => $code_rec, prec => $prec)
+# Returns the data structure used to represent the RHS:
+#      [ @rhs, $arg{prec}, $arg{name}, $arg{code}]
 sub rhs {
   my @rhs = @{shift()};
 
@@ -259,7 +263,7 @@ sub new {
 
   warn $warnmessage unless __PACKAGE__->isa('Parse::Eyapp::Driver'); 
   my($self)=$class->SUPER::new( 
-    yyversion => '1.134',
+    yyversion => '1.135',
     yyGRAMMAR  =>
 [
   [ _SUPERSTART => '$start', [ 'eyapp', '$end' ], 0 ],
@@ -1386,8 +1390,9 @@ sub {
                 unless ($$term{$_} || exists($$nterm{$_}));
               }
             }
-            # [ left hand side,   right hand side,  precedence, rulename, code, ??prefixofcode ]
-            $$rules[0]=[ '$start', [ $start, chr(0) ], undef, undef, undef,] # prefixofcode???  undef ];
+            # Superstart rule
+            # [ left hand side,   right hand side,  precedence, rulename, code, ]
+            $$rules[0]=[ '$start', [ $start, chr(0) ], undef, undef, undef,]  
         }
 ################ @@@@@@@@@ End of User Code @@@@@@@@@ ###################
 	],
